### Name: pvcovHC
### Title: Robust covariance matrix estimators
### Aliases: pvcovHC pvcovHC.panelmodel pvcovHC.pgmm
### Keywords: regression

### ** Examples

library(lmtest)
library(car)
library(Ecdat)
library(plm)
data(Produc)
Produc <-pdata.frame(Produc,"state","year")
zz <- plm(log(gsp)~log(pcap)+log(pc)+log(emp)+unemp,data=Produc,model="random")
## standard coefficient significance test
coeftest(zz)
## robust significance test
coeftest(zz, vcov=pvcovHC)
## idem with parameters, pass vcov as a function argument
coeftest(zz, vcov=function(x) pvcovHC(x, type="arellano", weights="HC1"))
## idem with parameters, pass vcov as a matrix argument
coeftest(zz, vcov=pvcovHC(zz, type="arellano", weights="HC1"))
## joint restriction test
waldtest(zz, update(zz, .~.-log(emp)-unemp), vcov=pvcovHC)
## test of hyp.: 2*log(pc)=log(emp)
linear.hypothesis(zz, "2*log(pc)=log(emp)", vcov=pvcovHC)

## Robust inference for GMM models
data(EmplUK)
pdata.frame(EmplUK,"firm","year")
ar <- pgmm(dynformula(log(emp)~log(wage)+log(capital)+log(output),list(2,1,2,2)),EmplUK,
           effect="twoways",model="twosteps",
           gmm.inst=~log(emp),lag.gmm=list(c(2,99)))
rv <- pvcovHC(ar)
mtest(ar,order=2,vcov=rv)




